@@ -1,10 +1,15 @@
 package SmokeRunner::Multi;
+BEGIN {
+  $SmokeRunner::Multi::AUTHORITY = 'cpan:YANICK';
+}
+{
+  $SmokeRunner::Multi::VERSION = '0.18';
+}
+#ABSTRACT: Manage smoke tests across multiple branches/checkouts/projects
 
 use strict;
 use warnings;
 
-our $VERSION = '0.17';
-
 use SmokeRunner::Multi::Config;
 use SmokeRunner::Multi::TestSet;
 
@@ -28,8 +33,6 @@ sub run_and_report_next_set
     my $set = $self->next_set()
         or return;
 
-    my $config = SmokeRunner::Multi::Config->instance();
-
     my $runner = $self->make_runner( set => $set );
 
     $set->update_files();
@@ -93,12 +96,18 @@ sub _class_for
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 SmokeRunner::Multi - Manage smoke tests across multiple branches/checkouts/projects
 
+=head1 VERSION
+
+version 0.18
+
 =head1 SYNOPSIS
 
   use SmokeRunner::Multi;
@@ -165,25 +174,30 @@ See the other classes in this distribution for more information:
 L<SmokeRunner::Multi::TestSet>, L<SmokeRunner::Multi::Runner>,
 L<SmokeRunner::Multi::Reporter>, and L<SmokeRunner::Multi::Config>.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Dave Rolsky, <autarch@urth.org>
 
-=head1 BUGS
+=item *
 
-Please report any bugs or feature requests to
-C<bug-smokerunner-multi@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Yanick Champoux <yanick@cpan.org>
 
-=head1 COPYRIGHT & LICENSE
+=back
 
-Copyright 2007 LiveText, Inc., All Rights Reserved.
+=head1 COPYRIGHT AND LICENSE
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is copyright (c) 2007 by LiveText, Inc..
 
-The full text of the license can be found in the LICENSE file included
-with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
+
