@@ -1,4 +1,11 @@
 package SmokeRunner::Multi::DBI;
+BEGIN {
+  $SmokeRunner::Multi::DBI::AUTHORITY = 'cpan:YANICK';
+}
+{
+  $SmokeRunner::Multi::DBI::VERSION = '0.18';
+}
+#ABSTRACT: DBI helpers for SmokeRunner::Multi
 
 use strict;
 use warnings;
@@ -50,12 +57,18 @@ EOF
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 SmokeRunner::Multi::DBI - DBI helpers for SmokeRunner::Multi
 
+=head1 VERSION
+
+version 0.18
+
 =head1 SYNOPSIS
 
   my $dbh = SmokeRunner::Multi::DBI::handle();
@@ -104,4 +117,30 @@ under the same terms as Perl itself.
 The full text of the license can be found in the LICENSE file included
 with this module.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Dave Rolsky, <autarch@urth.org>
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2007 by LiveText, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
+
