@@ -1,4 +1,11 @@
 package SmokeRunner::Multi::Reporter::Smolder;
+BEGIN {
+  $SmokeRunner::Multi::Reporter::Smolder::AUTHORITY = 'cpan:YANICK';
+}
+{
+  $SmokeRunner::Multi::Reporter::Smolder::VERSION = '0.18';
+}
+#ABSTRACT:  Reports test runs to a Smolder installation
 
 use strict;
 use warnings;
@@ -67,12 +74,18 @@ sub report
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 SmokeRunner::Multi::Reporter::Smolder - Reports test runs to a Smolder installation
 
+=head1 VERSION
+
+version 0.18
+
 =head1 SYNOPSIS
 
   my $reporter =
@@ -149,4 +162,30 @@ under the same terms as Perl itself.
 The full text of the license can be found in the LICENSE file included
 with this module.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Dave Rolsky, <autarch@urth.org>
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2007 by LiveText, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
+
