@@ -1,4 +1,11 @@
 package SmokeRunner::Multi::Runner::TAPArchive;
+BEGIN {
+  $SmokeRunner::Multi::Runner::TAPArchive::AUTHORITY = 'cpan:YANICK';
+}
+{
+  $SmokeRunner::Multi::Runner::TAPArchive::VERSION = '0.18';
+}
+#ABSTRACT: Runner subclass which creates a TAP archive file
 
 use strict;
 use warnings;
@@ -94,12 +101,18 @@ sub _libs
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 SmokeRunner::Multi::Runner::TAPArchive - Runner subclass which creates a TAP archive file
 
+=head1 VERSION
+
+version 0.18
+
 =head1 SYNOPSIS
 
   my $runner = SmokeRunner::Multi::Runner::TAPArchive->new( set => $set );
@@ -156,4 +169,30 @@ automatically be notified of progress on your bug as I make changes.
 
 Copyright 2007 LiveText, Inc., All Rights Reserved.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Dave Rolsky, <autarch@urth.org>
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2007 by LiveText, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
+
