@@ -1,4 +1,11 @@
 package SmokeRunner::Multi::SafeRun;
+BEGIN {
+  $SmokeRunner::Multi::SafeRun::AUTHORITY = 'cpan:YANICK';
+}
+{
+  $SmokeRunner::Multi::SafeRun::VERSION = '0.18';
+}
+#ABSTRACT: Run an external command safely in taint mode
 
 use strict;
 use warnings;
@@ -54,12 +61,18 @@ use IPC::Run3 qw( run3 );
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 SmokeRunner::Multi::SafeRun - Run an external command safely in taint mode
 
+=head1 VERSION
+
+version 0.18
+
 =head1 SYNOPSIS
 
   use SmokeRunner::Multi::SafeRun qw( safe_run );
@@ -138,4 +151,30 @@ it under the same terms as Perl itself.
 The full text of the license can be found in the LICENSE file included
 with this module.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Dave Rolsky, <autarch@urth.org>
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2007 by LiveText, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
+
