@@ -1,4 +1,11 @@
 package SmokeRunner::Multi::TestSet;
+BEGIN {
+  $SmokeRunner::Multi::TestSet::AUTHORITY = 'cpan:YANICK';
+}
+{
+  $SmokeRunner::Multi::TestSet::VERSION = '0.18';
+}
+#ABSTRACT: Represents a set of tests
 
 use strict;
 use warnings;
@@ -206,12 +213,18 @@ sub _sort_sets
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 SmokeRunner::Multi::TestSet - Represents a set of tests
 
+=head1 VERSION
+
+version 0.18
+
 =head1 SYNOPSIS
 
   my $set = SmokeRunner::Multi::TestSet->new( set_dir => 'path/to/set' );
@@ -343,4 +356,30 @@ it under the same terms as Perl itself.
 The full text of the license can be found in the LICENSE file included
 with this module.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Dave Rolsky, <autarch@urth.org>
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2007 by LiveText, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
+
