@@ -1,4 +1,11 @@
 package SmokeRunner::Multi::Validate;
+BEGIN {
+  $SmokeRunner::Multi::Validate::AUTHORITY = 'cpan:YANICK';
+}
+{
+  $SmokeRunner::Multi::Validate::VERSION = '0.18';
+}
+#ABSTRACT: Wrapper around Params::Validate for SmokeRunner::Multi
 
 use strict;
 use warnings;
@@ -77,12 +84,18 @@ EOF
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 SmokeRunner::Multi::Validate - Wrapper around Params::Validate for SmokeRunner::Multi
 
+=head1 VERSION
+
+version 0.18
+
 =head1 SYNOPSIS
 
   use SmokeRunner::Multi::Validate qw( validate DIR_TYPE TEST_SET_TYPE );
@@ -165,5 +178,31 @@ it under the same terms as Perl itself.
 The full text of the license can be found in the LICENSE file included
 with this module.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Dave Rolsky, <autarch@urth.org>
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2007 by LiveText, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+
+__END__
+
+
+
